@@ -110,7 +110,7 @@ UniqueAppHandler::~UniqueAppHandler()
 }
 
 // DBUS call
-int UniqueAppHandler::newInstance(const QByteArray &asn_id, const QStringList &args)
+int UniqueAppHandler::newInstance(const QByteArray &asn_id, const QStringList &args, const QString &workingDirectory)
 {
     if (!asn_id.isEmpty()) {
         KStartupInfo::setStartupId(asn_id);
@@ -120,15 +120,16 @@ int UniqueAppHandler::newInstance(const QByteArray &asn_id, const QStringList &a
     loadCommandLineOptions(&parser); // implemented by plugin
     parser.process(args);
 
-    return activate(args);
+    return activate(args, workingDirectory);
 }
 
 static QWidget *s_mainWidget = 0;
 
 // Plugin-specific newInstance implementation, called by above method
-int KontactInterface::UniqueAppHandler::activate(const QStringList &args)
+int KontactInterface::UniqueAppHandler::activate(const QStringList &args, const QString &workingDirectory)
 {
     Q_UNUSED(args);
+    Q_UNUSED(workingDirectory);
 
     if (s_mainWidget) {
         s_mainWidget->show();
@@ -155,7 +156,7 @@ bool KontactInterface::UniqueAppHandler::load()
 }
 
 //@cond PRIVATE
-class UniqueAppWatcher::Private
+class Q_DECL_HIDDEN UniqueAppWatcher::Private
 {
 public:
     UniqueAppHandlerFactoryBase *mFactory;
@@ -204,8 +205,8 @@ UniqueAppWatcher::UniqueAppWatcher(UniqueAppHandlerFactoryBase *factory, Plugin
 
     if (d->mRunningStandalone) {
         QObject::connect(QDBusConnection::sessionBus().interface(),
-                         SIGNAL(serviceOwnerChanged(QString,QString,QString)),
-                         this, SLOT(slotApplicationRemoved(QString,QString,QString)));
+                         &QDBusConnectionInterface::serviceOwnerChanged,
+                         this, &UniqueAppWatcher::slotApplicationRemoved);
     } else {
         d->mFactory->createHandler(d->mPlugin);
     }
