@@ -65,11 +65,11 @@ public:
     QWidget *mainWidget();
 
 public Q_SLOTS: // DBUS methods
-    int newInstance(const QByteArray &asn_id, const QStringList &args);
+    int newInstance(const QByteArray &asn_id, const QStringList &args, const QString &workingDirectory);
     bool load();
 
 protected:
-    virtual int activate(const QStringList &args);
+    virtual int activate(const QStringList &args, const QString &workingDirectory);
 
 private:
     class Private;
@@ -93,7 +93,7 @@ public:
 template <class T> class UniqueAppHandlerFactory : public UniqueAppHandlerFactoryBase
 {
 public:
-    virtual UniqueAppHandler *createHandler(Plugin *plugin)
+    UniqueAppHandler *createHandler(Plugin *plugin) Q_DECL_OVERRIDE
     {
         plugin->registerClient();
         return new T(plugin);
